==> homesitemaker-v0.4.5.tar.gz: homesitemaker/includes/control-panel/users/cp_add_user.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-control-panel-users-cp_add_user.php");
echo "<tr><td class=\"title1\" colspan=\"2\">$TEXT001<br>&nbsp;</td></tr>".
      "<tr><td class=\"text2\" colspan=\"2\">$TEXT002</td></tr>";


// If the user was loged in and select the add users option (task=add), add privileged users.
if ($id_session[num] == $num && $task=="add" && $id_session[num] != "")
  {
  echo "<form enctype=\"multipart/form-data\" method=\"post\"".
       " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&user_section=2\">".
       "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_user\">".
       "<input type=\"hidden\" name=\"num\" value=\"$num\">".
       "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT003:</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"new_nick\" value=\"\"></input></tr>".
       "<tr><td class=\"text2\" colspan=2><br><b>$TEXT004:</b>($TEXT005)</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"real_name\" value=\"\"></input></tr>".
       "<tr><td class=\"text2\" colspan=2><br><b>$TEXT006:</b>($TEXT005)</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"email\" value=\"\"></input></tr>".
       "<tr><td class=\"text2\" colspan=2><br><b>$TEXT007:</b>&nbsp;($TEXT005)</td></tr>".
       "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"user_photo[]\" size=40>".
       "&nbsp;&nbsp;&nbsp;</input></td></tr>".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT008:</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"select\" size=40 name=\"level\" value=\"\"></input></tr>".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT009:</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"password\" size=40 name=\"password\" value=\"\"></input></tr>".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT010:</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"password\" size=40 name=\"password_check\" value=\"\"></input></tr>".
       "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><br><input type=\"submit\" ".
       "value=\"$TEXT011\"></input><br></td></tr>".
       "</form>";
  } else { // Unprivileged or anonymous visitors can only add unprivileged users.
         echo "<form enctype=\"multipart/form-data\" method=\"post\" action=\"index.php\">".
              "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_unprivileged_user\">".
              "<input type=\"hidden\" name=\"num\" value=\"$num\">".
              "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">".
              "<tr><td class=\"text2b\" colspan=2><br>$TEXT003:</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"new_nick\" value=\"\"></input></tr>".
              "<tr><td class=\"text2\" colspan=2><br><b>$TEXT004:</b>($TEXT005)</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"real_name\" value=\"\"></input></tr>".
              "<tr><td class=\"text2\" colspan=2><br><b>$TEXT006:</b>($TEXT005)</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"email\" value=\"\"></input></tr>".
              "<tr><td class=\"text2\" colspan=2><br><b>$TEXT007:</b>&nbsp;($TEXT005)</td></tr>".
              "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"user_photo[]\" ".
              "size=40>&nbsp;&nbsp;&nbsp;</input></td></tr>".
              "<tr><td class=\"text2b\" colspan=2><br>$TEXT009:</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"password\" size=40 name=\"password\" value=\"\"></input></tr>".
              "<tr><td class=\"text2b\" colspan=2><br>$TEXT010:</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"password\" size=40 name=\"password_check\" value=\"\"></input></tr>".
              "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><br><input type=\"submit\" ".
              "value=\"$TEXT011\"></input><br></td></tr>".
              "</form>";
         } 
 
?>

==> homesitemaker-v0.4.7-1.tar.gz: homesitemaker/includes/control-panel/users/cp_add_user.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-control-panel-users-cp_add_user.php");
echo "<tr><td class=\"title1\" colspan=\"2\"><img src=\"images/skins/$ICONS/icons/png/$ICON_SIZE2/Add_Users.png\"> $TEXT001<br>&nbsp;</td></tr>".
      "<tr><td class=\"text2\" colspan=\"2\">$TEXT002</td></tr>";


// If the user was loged in and select the add users option (task=add), add privileged users.
if ($id_session[num] == $num && $task=="add" && $id_session[num] != "")
  {
  echo "<form enctype=\"multipart/form-data\" method=\"post\"".
       " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&user_section=2\">".
       "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_user\">".
       "<input type=\"hidden\" name=\"num\" value=\"$num\">".
       "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT003:</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"new_nick\" value=\"\"></input></tr>".
       "<tr><td class=\"text2\" colspan=2><br><b>$TEXT004:</b>($TEXT005)</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"real_name\" value=\"\"></input></tr>".
       "<tr><td class=\"text2\" colspan=2><br><b>$TEXT006:</b>($TEXT005)</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"email\" value=\"\"></input></tr>".
       "<tr><td class=\"text2\" colspan=2><br><b>$TEXT007:</b>&nbsp;($TEXT005)</td></tr>".
       "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"user_photo[]\" size=40>".
       "&nbsp;&nbsp;&nbsp;</input></td></tr>".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT008:</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"select\" size=40 name=\"level\" value=\"\"></input></tr>".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT009:</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"password\" size=40 name=\"password\" value=\"\"></input></tr>".
       "<tr><td class=\"text2b\" colspan=2><br>$TEXT010:</td></tr>".
       "<tr><td colspan=\"2\"><input type=\"password\" size=40 name=\"password_check\" value=\"\"></input></tr>".
       "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><br><input type=\"submit\" ".
       "value=\"$TEXT011\"></input><br></td></tr>".
       "</form>";
  } else { // Unprivileged or anonymous visitors can only add unprivileged users.
         echo "<form enctype=\"multipart/form-data\" method=\"post\" action=\"index.php\">".
              "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_unprivileged_user\">".
              "<input type=\"hidden\" name=\"num\" value=\"$num\">".
              "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">".
              "<tr><td class=\"text2b\" colspan=2><br>$TEXT003:</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"new_nick\" value=\"\"></input></tr>".
              "<tr><td class=\"text2\" colspan=2><br><b>$TEXT004:</b>($TEXT005)</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"real_name\" value=\"\"></input></tr>".
              "<tr><td class=\"text2\" colspan=2><br><b>$TEXT006:</b>($TEXT005)</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"text\" size=40 name=\"email\" value=\"\"></input></tr>".
              "<tr><td class=\"text2\" colspan=2><br><b>$TEXT007:</b>&nbsp;($TEXT005)</td></tr>".
              "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"user_photo[]\" ".
              "size=40>&nbsp;&nbsp;&nbsp;</input></td></tr>".
              "<tr><td class=\"text2b\" colspan=2><br>$TEXT009:</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"password\" size=40 name=\"password\" value=\"\"></input></tr>".
              "<tr><td class=\"text2b\" colspan=2><br>$TEXT010:</td></tr>".
              "<tr><td colspan=\"2\"><input type=\"password\" size=40 name=\"password_check\" value=\"\"></input></tr>".
              "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><br><input type=\"submit\" ".
              "value=\"$TEXT011\"></input><br></td></tr>".
              "</form>";
         } 
 
?>
